summaryrefslogtreecommitdiffstats
path: root/src/entry.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/entry.h')
-rw-r--r--src/entry.h66
1 files changed, 34 insertions, 32 deletions
diff --git a/src/entry.h b/src/entry.h
index 739b128..be0eef9 100644
--- a/src/entry.h
+++ b/src/entry.h
@@ -1,12 +1,12 @@
/******************************************************************************
*
- *
+ *
*
* Copyright (C) 1997-2015 by Dimitri van Heesch.
*
* Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby
- * granted. No representations are made about the suitability of this software
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
* for any purpose. It is provided "as is" without express or implied warranty.
* See the GNU General Public License for more details.
*
@@ -33,21 +33,21 @@ class ArgumentList;
struct ListItemInfo;
/** This class stores information about an inheritance relation
- */
-struct BaseInfo
+ */
+struct BaseInfo
{
/*! Creates an object representing an inheritance relation */
- BaseInfo(const char *n,Protection p,Specifier v) :
+ BaseInfo(const char *n,Protection p,Specifier v) :
name(n),prot(p),virt(v) {}
QCString name; //!< the name of the base class
Protection prot; //!< inheritance type
Specifier virt; //!< virtualness
};
-/** This struct is used to capture the tag file information
- * for an Entry.
+/** This struct is used to capture the tag file information
+ * for an Entry.
*/
-struct TagInfo
+struct TagInfo
{
QCString tagName;
QCString fileName;
@@ -55,7 +55,7 @@ struct TagInfo
};
/** Represents an unstructured piece of information, about an
- * entity found in the sources.
+ * entity found in the sources.
*
* parseMain() in scanner.l will generate a tree of these
* entries.
@@ -65,13 +65,13 @@ class Entry
public:
/*! Kind of entries that are supported */
- enum Sections {
- CLASS_SEC = 0x00000001,
+ enum Sections {
+ CLASS_SEC = 0x00000001,
NAMESPACE_SEC = 0x00000010,
COMPOUND_MASK = CLASS_SEC,
SCOPE_MASK = COMPOUND_MASK | NAMESPACE_SEC,
-
- CLASSDOC_SEC = 0x00000800,
+
+ CLASSDOC_SEC = 0x00000800,
STRUCTDOC_SEC = 0x00001000,
UNIONDOC_SEC = 0x00002000,
EXCEPTIONDOC_SEC = 0x00004000,
@@ -81,7 +81,7 @@ class Entry
CATEGORYDOC_SEC = 0x00040000,
SERVICEDOC_SEC = 0x00080000,
SINGLETONDOC_SEC = 0x00100000,
- COMPOUNDDOC_MASK = CLASSDOC_SEC | STRUCTDOC_SEC | UNIONDOC_SEC |
+ COMPOUNDDOC_MASK = CLASSDOC_SEC | STRUCTDOC_SEC | UNIONDOC_SEC |
INTERFACEDOC_SEC | EXCEPTIONDOC_SEC | PROTOCOLDOC_SEC |
CATEGORYDOC_SEC | SERVICEDOC_SEC | SINGLETONDOC_SEC,
@@ -134,7 +134,8 @@ class Entry
static const uint64 Enum = (1ULL<<12); // for Java-style enums
static const uint64 Service = (1ULL<<13); // UNO IDL
static const uint64 Singleton = (1ULL<<14); // UNO IDL
- static const uint64 ForwardDecl = (1ULL<<15); // forward declarad template classes
+ static const uint64 ForwardDecl = (1ULL<<15); // forward declared template classes
+ static const uint64 Local = (1ULL<<16); // for Slice types
// member specifiers (add new items to the beginning)
static const uint64 PrivateGettable = (1ULL<<20); // C# private getter
@@ -205,7 +206,7 @@ class Entry
/*! Returns the parent for this Entry or 0 if this entry has no parent. */
Entry *parent() const { return m_parent; }
- /*! Returns the list of children for this Entry
+ /*! Returns the list of children for this Entry
* @see addSubEntry() and removeSubEntry()
*/
const QList<Entry> *children() const { return m_sublist; }
@@ -213,14 +214,14 @@ class Entry
/*! Adds entry \a e as a child to this entry */
void addSubEntry (Entry* e) ;
- /*! Removes entry \a e from the list of children.
- * Returns a pointer to the entry or 0 if the entry was not a child.
+ /*! Removes entry \a e from the list of children.
+ * Returns a pointer to the entry or 0 if the entry was not a child.
* Note the entry will not be deleted.
- */
+ */
Entry *removeSubEntry(Entry *e);
/*! Restore the state of this Entry to the default value it has
- * at construction time.
+ * at construction time.
*/
void reset();
@@ -234,7 +235,7 @@ class Entry
// identification
int section; //!< entry type (see Sections);
- QCString type; //!< member type
+ QCString type; //!< member type
QCString name; //!< member name
TagInfo *tagInfo; //!< tag file info
@@ -242,14 +243,14 @@ class Entry
Protection protection; //!< class protection
MethodTypes mtype; //!< signal, slot, (dcop) method, or property?
uint64 spec; //!< class/member specifiers
- int initLines; //!< define/variable initializer lines to show
+ int initLines; //!< define/variable initializer lines to show
bool stat; //!< static ?
bool explicitExternal; //!< explicitly defined as external?
bool proto; //!< prototype ?
bool subGrouping; //!< automatically group class members?
bool callGraph; //!< do we need to draw the call graph?
bool callerGraph; //!< do we need to draw the caller graph?
- Specifier virt; //!< virtualness of the entry
+ Specifier virt; //!< virtualness of the entry
QCString args; //!< member argument string
QCString bitfields; //!< member's bit fields
ArgumentList *argList; //!< member arguments as a list
@@ -277,7 +278,7 @@ class Entry
int bodyLine; //!< line number of the definition in the source
int endBodyLine; //!< line number where the definition ends
int mGrpId; //!< member group id
- QList<BaseInfo> *extends; //!< list of base classes
+ QList<BaseInfo> *extends; //!< list of base classes
QList<Grouping> *groups; //!< list of groups this entry belongs to
QList<SectionInfo> *anchors; //!< list of anchors defined in this entry
QCString fileName; //!< file this entry was extracted from
@@ -290,6 +291,7 @@ class Entry
GroupDocType groupDocType;
QCString id; //!< libclang id
LocalToc localToc;
+ QCString metaData; //!< Slice metadata
static int num; //!< counts the total number of entries
@@ -297,7 +299,7 @@ class Entry
/// return the command name used to define GROUPDOC_SEC
const char *groupDocCmd() const
{
- switch( groupDocType )
+ switch( groupDocType )
{
case GROUPDOC_NORMAL: return "\\defgroup";
case GROUPDOC_ADD: return "\\addgroup";
@@ -307,11 +309,11 @@ class Entry
}
Grouping::GroupPri_t groupingPri() const
{
- if( section != GROUPDOC_SEC )
+ if( section != GROUPDOC_SEC )
{
return Grouping::GROUPING_LOWEST;
}
- switch( groupDocType )
+ switch( groupDocType )
{
case GROUPDOC_NORMAL: return Grouping::GROUPING_AUTO_DEF;
case GROUPDOC_ADD: return Grouping::GROUPING_AUTO_ADD;
@@ -320,11 +322,11 @@ class Entry
}
}
- private:
+ private:
void createSubtreeIndex(EntryNav *nav,FileStorage *storage,FileDef *fd);
Entry *m_parent; //!< parent node in the tree
QList<Entry> *m_sublist; //!< entries that are children of this one
- Entry &operator=(const Entry &);
+ Entry &operator=(const Entry &);
};
/** Wrapper for a node in the Entry tree.
@@ -357,13 +359,13 @@ class EntryNav
private:
- // navigation
+ // navigation
EntryNav *m_parent; //!< parent node in the tree
QList<EntryNav> *m_subList; //!< entries that are children of this one
// identification
int m_section; //!< entry type (see Sections);
- QCString m_type; //!< member type
+ QCString m_type; //!< member type
QCString m_name; //!< member name
TagInfo *m_tagInfo; //!< tag file info
FileDef *m_fileDef;